@@ -20,4 +20,7 @@ class StationOwnerPermission(permissions.BasePermission):
             return True
         if request.method == 'POST' and schedule_perms(request.user):
             return True
-        return request.user.is_authenticated and request.user == obj.ground_station.owner
+        return (
+            request.user.is_authenticated and obj.ground_station
+            and request.user == obj.ground_station.owner
+        )
