@@ -1,17 +1,16 @@
 """Django database base model for SatNOGS Network"""
 import codecs
-import logging
 import os
 import re
 from datetime import timedelta
 
-import requests
 from django.conf import settings
 from django.core.cache import cache
 from django.core.exceptions import ValidationError
 from django.core.validators import MaxLengthValidator, MaxValueValidator, MinLengthValidator, \
     MinValueValidator
 from django.db import models
+from django.db.models import Count, Q
 from django.dispatch import receiver
 from django.urls import reverse
 from django.utils.html import format_html
@@ -144,12 +143,18 @@ class Station(models.Model):
         rate = cache.get('station-{0}-rate'.format(self.id))
         if not rate:
             observations = self.observations.exclude(testing=True).exclude(status__range=(0, 99))
-            success = observations.filter(
-                id__in=(o.id for o in observations if o.status >= 100 or -100 <= o.status < 0)
-            ).count()
-            if observations:
-                rate = int(100 * (success / observations.count()))
-                cache.set('station-{0}-rate'.format(self.id), rate)
+            stats = observations.aggregate(
+                bad=Count('pk', filter=Q(status__range=(-100, -1))),
+                good=Count('pk', filter=Q(status__gte=100)),
+                failed=Count('pk', filter=Q(status__lt=100))
+            )
+            good_count = 0 if stats['good'] is None else stats['good']
+            bad_count = 0 if stats['bad'] is None else stats['bad']
+            failed_count = 0 if stats['failed'] is None else stats['failed']
+            total = good_count + bad_count + failed_count
+            if total:
+                rate = int(100 * ((bad_count + good_count) / total))
+                cache.set('station-{0}-rate'.format(self.id), rate, 60 * 60 * 6)
             else:
                 rate = False
         return rate
@@ -370,7 +375,8 @@ class Observation(models.Model):
     rise_azimuth = models.FloatField(blank=True, null=True)
     max_altitude = models.FloatField(blank=True, null=True)
     set_azimuth = models.FloatField(blank=True, null=True)
-    archived = models.BooleanField(default=False)
+    audio_zipped = models.BooleanField(default=False, db_index=True)
+    archived = models.BooleanField(default=False, db_index=True)
     archive_identifier = models.CharField(max_length=255, blank=True)
     archive_url = models.URLField(blank=True, null=True)
     transmitter_uuid = ShortUUIDField(auto=False, db_index=True)
@@ -502,18 +508,8 @@ class Observation(models.Model):
         """Return url for observation's audio file"""
         if self.has_audio:
             if self.archive_url:
-                try:
-                    request = requests.get(self.archive_url, allow_redirects=False)
-                    request.raise_for_status()
-
-                    url = request.headers['Location']
-                    return url
-                except requests.exceptions.RequestException as error:
-                    logger = logging.getLogger(__name__)
-                    logger.warning("Error in request to '%s'. Error: %s", self.archive_url, error)
-                    return ''
-            else:
-                return self.payload.url
+                return 'archived'
+            return self.payload.url
         return ''
 
     class Meta:
