@@ -35,6 +35,7 @@ THIRD_PARTY_APPS = (
     'avatar',
     'rest_framework',
     'rest_framework.authtoken',
+    'drf_spectacular',
     'django_filters',
     'crispy_forms',
     'allauth',
@@ -52,8 +53,8 @@ LOCAL_APPS = (
 if DEBUG:
     DJANGO_APPS += ('debug_toolbar', )
     DEBUG_TOOLBAR_CONFIG = {
-        'SHOW_TOOLBAR_CALLBACK':
-        lambda request: request.environ.get('SERVER_NAME', None) != 'testserver',
+        'SHOW_TOOLBAR_CALLBACK': lambda request: request.environ.get('SERVER_NAME', None) !=
+        'testserver',
     }
 if AUTH0:
     THIRD_PARTY_APPS += ('social_django', )
@@ -96,8 +97,10 @@ SERVER_EMAIL = DEFAULT_FROM_EMAIL
 # Cache
 CACHES = {
     'default': {
-        'BACKEND':
-        config('CACHE_BACKEND', default='django.core.cache.backends.locmem.LocMemCache'),
+        'BACKEND': config(
+            'CACHE_BACKEND',
+            default='django.core.cache.backends.locmem.LocMemCache',
+        ),
         'LOCATION': config('CACHE_LOCATION', default='unique-location'),
         'OPTIONS': {
             'MAX_ENTRIES': 5000,
@@ -276,10 +279,42 @@ CELERY_BROKER_TRANSPORT_OPTIONS = {
 
 # API
 REST_FRAMEWORK = {
-    'DEFAULT_PERMISSION_CLASSES':
-    ('rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly', ),
+    'DEFAULT_PERMISSION_CLASSES': (
+        'rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly',
+    ),
     'DEFAULT_AUTHENTICATION_CLASSES': ('rest_framework.authentication.TokenAuthentication', ),
-    'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend', )
+    'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend', ),
+    'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
+}
+SPECTACULAR_DEFAULTS = {
+    'SCHEMA_PATH_PREFIX': r'/api',
+    'DEFAULT_GENERATOR_CLASS': 'drf_spectacular.generators.SchemaGenerator',
+    'COMPONENT_SPLIT_REQUEST': True,
+    'TITLE': 'SatNOGS Network',
+    'DESCRIPTION': 'SatNOGS Network is a web application, implementing a global scheduling and'
+    'monitoring network for ground station operations.',
+    'CONTACT': {
+        'name': 'SatNOGS Developer Chat',
+        'url': 'https://riot.im/app/#/room/#satnogs-dev:matrix.org'
+    },
+    'LICENSE': {
+        'name': 'AGPL 3.0',
+        'url': 'https://www.gnu.org/licenses/agpl-3.0.html'
+    },
+    'VERSION': '1.1',
+    'SERVERS': [
+        {
+            'url': 'https://network-dev.satnogs.org',
+            'description': 'Development server'
+        }, {
+            'url': 'https://network.satnogs.org',
+            'description': 'Production server'
+        }
+    ],
+    'EXTERNAL_DOCS': {
+        'url': 'https://wiki.satnogs.org',
+        'description': 'SatNOGS Wiki'
+    },
 }
 
 # Security
@@ -378,7 +413,7 @@ STATION_HEARTBEAT_TIME = config('STATION_HEARTBEAT_TIME', default=60, cast=int)
 # Maximum window for upcoming passes in hours
 STATION_UPCOMING_END = config('STATION_UPCOMING_END', default=24, cast=int)
 WIKI_STATION_URL = config('WIKI_STATION_URL', default='https://wiki.satnogs.org/')
-MAX_ANTENNAS_PER_STATION = config('MAX_ANTENNAS_PER_STATION', default=3, cast=int)
+MAX_ANTENNAS_PER_STATION = config('MAX_ANTENNAS_PER_STATION', default=4, cast=int)
 MAX_FREQUENCY_RANGES_PER_ANTENNA = config('MAX_FREQUENCY_RANGES_PER_ANTENNA', default=5, cast=int)
 MAX_FREQUENCY_FOR_RANGE = config('MAX_FREQUENCY_FOR_RANGE', default=40000000000, cast=int)
 MIN_FREQUENCY_FOR_RANGE = config('MIN_FREQUENCY_FOR_RANGE', default=300, cast=int)
@@ -419,13 +454,38 @@ ITEMS_PER_PAGE = config('ITEMS_PER_PAGE', default=25, cast=int)
 # User settings
 AVATAR_GRAVATAR_DEFAULT = config('AVATAR_GRAVATAR_DEFAULT', default='mm')
 
+# Cache expiration of the lock for "process audio" task
+PROCESS_AUDIO_LOCK_EXPIRATION = config('PROCESS_AUDIO_LOCK_EXPIRATION', default=900, cast=int)
+
+# Audio zip
+ZIP_AUDIO_FILES = config('ZIP_AUDIO_FILES', default=False, cast=bool)
+AUDIO_FILES_PER_ZIP = config('AUDIO_FILES_PER_ZIP', default=1000, cast=int)
+ZIP_FILE_PREFIX = config('ZIP_FILE_PREFIX', default='satnogs-observations')
+# Audio zip - Expiration time for access lock when append audio file to zip
+ZIP_AUDIO_LOCK_EXPIRATION = config('ZIP_AUDIO_LOCK_EXPIRATION', default=600, cast=int)
+# Audio zip - Cache expiration of the lock for "zip audio" task
+ZIP_TASK_LOCK_EXPIRATION = config('ZIP_TASK_LOCK_EXPIRATION', default=3600, cast=int)
+
 # Archive.org
+ARCHIVE_ZIP_FILES = config('ARCHIVE_ZIP_FILES', default=False, cast=bool)
+ZIP_FILES_PER_ITEM = config('ZIP_FILES_PER_ITEM', default=10, cast=int)
+ITEM_IDENTIFIER_PREFIX = config('ITEM_IDENTIFIER_PREFIX', default='satnogs-observations')
+ITEM_TITLE_PREFIX = config('ITEM_TITLE_PREFIX', default='SatNOGS Observations')
+# Archive.org - Cache expiration of the lock for "archive audio" task
+ARCHIVE_TASK_LOCK_EXPIRATION = config('ARCHIVE_TASK_LOCK_EXPIRATION', default=86400, cast=int)
+# Archive.org - Expiration time for access lock when archiving zip file
+ARCHIVE_ZIP_LOCK_EXPIRATION = config('ARCHIVE_ZIP_LOCK_EXPIRATION', default=21600, cast=int)
+# Archive.org - Hours from end time of the timely last observation of a group
+ARCHIVE_SKIP_TIME = config('ARCHIVE_SKIP_TIME', default=48, cast=int)
 S3_ACCESS_KEY = config('S3_ACCESS_KEY', default='')
 S3_SECRET_KEY = config('S3_SECRET_KEY', default='')
 S3_RETRIES_ON_SLOW_DOWN = config('S3_RETRIES_ON_SLOW_DOWN', default=1, cast=int)
 S3_RETRIES_SLEEP = config('S3_RETRIES_SLEEP', default=30, cast=int)
 ARCHIVE_COLLECTION = config('ARCHIVE_COLLECTION', default='test_collection')
+ARCHIVE_MEDIA_TYPE = config('ARCHIVE_MEDIA_TYPE', default='data')
 ARCHIVE_URL = 'https://archive.org/download/'
+REMOVE_ARCHIVED_AUDIO_FILES = config('REMOVE_ARCHIVED_AUDIO_FILES', default=False, cast=bool)
+REMOVE_ARCHIVED_ZIP_FILE = config('REMOVE_ARCHIVED_ZIP_FILE', default=False, cast=bool)
 
 if AUTH0:
     SOCIAL_AUTH_TRAILING_SLASH = False  # Remove end slash from routes
